Authorization

Struct Authorization 

pub struct Authorization<C>
where C: HttpClient,
{ /* private fields */ }
Authorization token and related information obtained from authorize_account.

The token is valid for no more than 24 hours.

Implementations

Source

impl<C> Authorization<C>
where C: HttpClient,

pub fn authorization_token(&self) -> &str

The authorization token used for Backblaze requests.

pub fn account_id(&self) -> &str

The ID for the account.

pub fn capabilities(&self) -> &Capabilities

The capabilities granted to this auth token.

pub fn recommended_part_size(&self) -> u64

The recommended size in bytes for each part of a large file.

pub fn minimum_part_size(&self) -> u64

The smallest possible size in bytes of a part of a large file, except the final part.

pub fn has_capability(&self, cap: Capability) -> bool