Module client

Module client 

HTTP client wrappers.

Errors from the backend HTTP client are passed to user code, so dealing with errors is inconsistent between implementations; if you switch from one backend to another, your code that inspects errors will need to be updated.

To use a custom HTTP client backend, implement HttpClient over an object that wraps your client.

Macros

default_user_agent
Generate a standard User-Agent string for HTTP client backends.

Traits

HttpClient
A trait that wraps an HTTP client to send HTTP requests.

Type Aliases

HeaderMap