pub struct Authorization<C>where
C: HttpClient,{ /* private fields */ }Expand description
Authorization token and related information obtained from authorize_account.
The token is valid for no more than 24 hours.
Implementations
Sourceimpl<C> Authorization<C>where
C: HttpClient,
impl<C> Authorization<C>where
C: HttpClient,
The authorization token used for Backblaze requests.
Sourcepub fn account_id(&self) -> &str
pub fn account_id(&self) -> &str
The ID for the account.
Sourcepub fn capabilities(&self) -> &Capabilities
pub fn capabilities(&self) -> &Capabilities
The capabilities granted to this auth token.
Sourcepub fn recommended_part_size(&self) -> u64
pub fn recommended_part_size(&self) -> u64
The recommended size in bytes for each part of a large file.
Sourcepub fn minimum_part_size(&self) -> u64
pub fn minimum_part_size(&self) -> u64
The smallest possible size in bytes of a part of a large file, except the final part.
pub fn has_capability(&self, cap: Capability) -> bool